@@ -1,8 +1,9 @@
-
+from api.bag import adres_uitgebreid
 
 def add_one(number):
     return number + 1
 
 if __name__ == "__main__":
     x = add_one(2)
-    print(x)
\ No newline at end of file
+    print(x)
+    adres_uitgebreid()
\ No newline at end of file
